@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -726,6 +726,14 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] ETC_UTC = new String[] {
+               "Am Uil\u00edoch L\u00e1rnach",
+               "UTC",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Mauritius = new String[] {
                "Am Caighde\u00e1nach Oile\u00e1n Mhuir\u00eds",
                "",
@@ -1273,16 +1281,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
-            { "UTC",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "UTC", ETC_UTC },
             { "Asia/Aden", Arabian },
             { "timezone.excity.America/Phoenix", "Phoenix" },
             { "timezone.excity.America/Antigua", "Antigua" },
@@ -1308,6 +1307,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             },
             { "timezone.excity.Antarctica/Vostok", "Vostok" },
             { "America/Panama", America_Eastern },
+            { "JST", Japan },
             { "timezone.excity.Pacific/Fiji", "Fids\u00ed" },
             { "timezone.excity.Europe/Gibraltar", "Giobr\u00e1ltar" },
             { "Europe/Jersey", GMT },
@@ -1327,6 +1327,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Tallinn", "Taillinn" },
             { "Asia/Phnom_Penh", Indochina },
             { "Africa/Kigali", Africa_Central },
+            { "BET", Brasilia },
             { "timezone.excity.Pacific/Guam", "Guam" },
             { "timezone.excity.Europe/Vaduz", "Vad\u00fas" },
             { "America/Argentina/Salta", Argentina },
@@ -1465,6 +1466,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "timezone.excity.America/Thule", "Thule" },
             { "timezone.excity.America/Grand_Turk", "Grand Turk" },
             { "America/Yakutat", Alaska },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "Europe/Vienna", Europe_Central },
             { "timezone.excity.America/Winnipeg", "Winnipeg" },
             { "timezone.excity.Antarctica/Macquarie", "Mac Guaire" },
@@ -1512,6 +1514,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "Pacific/Truk", Truk },
             { "timezone.excity.Africa/Conakry", "Conacra\u00ed" },
             { "timezone.excity.Asia/Jakarta", "Iac\u00e1rta" },
+            { "SST", Solomon },
             { "America/Jamaica", America_Eastern },
             { "Asia/Bishkek", Kyrgystan },
             { "Atlantic/Stanley", Falkland },
@@ -1533,6 +1536,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "timezone.excity.Indian/Mahe", "Mahe" },
             { "Europe/San_Marino", Europe_Central },
             { "America/Indiana/Tell_City", America_Central },
+            { "BST", Bangladesh },
             { "timezone.excity.Europe/Isle_of_Man", "Oile\u00e1n Mhanann" },
             { "Pacific/Saipan", Chamorro },
             { "timezone.excity.America/Curacao", "Cura\u00e7ao" },
@@ -1541,6 +1545,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "Antarctica/Rothera", Rothera },
             { "timezone.excity.America/Guyana", "an Ghu\u00e1in" },
             { "Asia/Damascus", Europe_Eastern },
+            { "MIT", Apia },
             { "America/Argentina/San_Luis", Argentina_Western },
             { "timezone.excity.Europe/Paris", "P\u00e1ras" },
             { "timezone.excity.Europe/Zagreb", "S\u00e1grab" },
@@ -1558,16 +1563,6 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Chita", "Chita" },
             { "America/Indiana/Marengo", America_Eastern },
             { "timezone.excity.America/Rankin_Inlet", "Rankin Inlet" },
-            { "America/Punta_Arenas",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "timezone.excity.America/Santarem", "Santar\u00e9m" },
             { "timezone.excity.Asia/Tomsk", "Tomsk" },
             { "timezone.excity.Europe/Helsinki", "Heilsinc\u00ed" },
@@ -1652,17 +1647,8 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "Europe/Tallinn", Europe_Eastern },
             { "Africa/Johannesburg", Africa_Southern },
             { "timezone.excity.Pacific/Fakaofo", "Fakaofo" },
+            { "EAT", Africa_Eastern },
             { "Africa/Bangui", Africa_Western },
-            { "Europe/Astrakhan",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Juba", Africa_Eastern },
             { "America/Campo_Grande", Amazon },
             { "America/Belem", Brasilia },
@@ -1683,6 +1669,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "America/Whitehorse", America_Pacific },
             { "timezone.excity.America/Cuiaba", "Cuiab\u00e1" },
             { "Pacific/Noumea", New_Caledonia },
+            { "ECT", Europe_Central },
             { "timezone.excity.Atlantic/Azores", "na hAs\u00f3ir" },
             { "timezone.excity.Australia/Melbourne", "Melbourne" },
             { "America/Montreal", America_Eastern },
@@ -1710,6 +1697,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "timezone.excity.America/Regina", "Regina" },
             { "SystemV/YST9YDT", Alaska },
             { "America/Merida", America_Central },
+            { "CAT", Africa_Central },
             { "America/St_Kitts", Atlantic },
             { "timezone.excity.America/Thunder_Bay", "Thunder Bay" },
             { "America/Fort_Nelson", America_Mountain },
@@ -1719,7 +1707,6 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "Africa/Monrovia", GMT },
             { "Asia/Ust-Nera", Vladivostok },
             { "timezone.excity.America/Louisville", "Louisville" },
-            { "timezone.excity.America/Cancun", "Canc\u00fan" },
             { "timezone.excity.Australia/Broken_Hill", "Broken Hill" },
             { "timezone.excity.Europe/Kaliningrad", "Kaliningrad" },
             { "America/North_Dakota/New_Salem", America_Central },
@@ -1733,16 +1720,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "Europe/Vatican", Europe_Central },
             { "timezone.excity.America/Asuncion", "As\u00fainseon" },
             { "Asia/Amman", Europe_Eastern },
-            { "Etc/UTC",
-                new String[] {
-                    "Am Uil\u00edoch L\u00e1rnach",
-                    "UTC",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "Etc/UTC", ETC_UTC },
             { "timezone.excity.Europe/Chisinau", "C\u00edsine\u00e1" },
             { "timezone.excity.America/Moncton", "Moncton" },
             { "Asia/Singapore", Singapore },
@@ -1796,6 +1774,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "Europe/Isle_of_Man", GMT },
             { "America/Araguaina", Brasilia },
             { "timezone.excity.Pacific/Easter", "Oile\u00e1n na C\u00e1sca" },
+            { "ACT", Australia_Central },
             { "Asia/Novosibirsk", Novosibirsk },
             { "Africa/Tunis", Europe_Central },
             { "Pacific/Fakaofo", Tokelau },
@@ -1822,6 +1801,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Kirov", "Kirov" },
             { "timezone.excity.America/Creston", "Creston" },
             { "timezone.excity.Africa/Cairo", "Caireo" },
+            { "AET", Australia_Eastern },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "timezone.excity.Europe/Warsaw", "V\u00e1rs\u00e1" },
             { "Europe/Skopje", Europe_Central },
@@ -1831,16 +1811,6 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "Africa/Algiers", Europe_Central },
             { "Europe/Mariehamn", Europe_Eastern },
             { "America/Anguilla", Atlantic },
-            { "Europe/Saratov",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Europe/Gibraltar", Europe_Central },
             { "Africa/Conakry", GMT },
             { "America/Havana", Cuba },
@@ -1877,16 +1847,6 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "America/Port_of_Spain", Atlantic },
             { "Asia/Beirut", Europe_Eastern },
             { "timezone.excity.Asia/Baghdad", "Bagdad" },
-            { "Pacific/Bougainville",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Sao_Tome", Africa_Western },
             { "Indian/Chagos", Indian_Ocean },
             { "timezone.excity.America/Metlakatla", "Metlakatla" },
@@ -1899,6 +1859,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "timezone.excity.America/Panama", "Panama" },
             { "timezone.excity.Europe/Simferopol", "Simferopol" },
             { "timezone.excity.Indian/Kerguelen", "Kerguelen" },
+            { "CNT", Newfoundland },
             { "timezone.excity.Europe/Volgograd", "Volgograd" },
             { "timezone.excity.Europe/Monaco", "Monac\u00f3" },
             { "Asia/Tashkent", Uzbekistan },
@@ -1920,6 +1881,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "timezone.excity.America/Managua", "Managua" },
             { "America/Kralendijk", Atlantic },
             { "Indian/Christmas", Christmas },
+            { "NET", Armenia },
             { "America/Inuvik", America_Mountain },
             { "America/Iqaluit", America_Eastern },
             { "Pacific/Funafuti", Tuvalu },
@@ -1963,11 +1925,13 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "Asia/Chongqing", China },
             { "America/Indiana/Knox", America_Central },
             { "timezone.excity.Asia/Saigon", "Cathair Ho Chi Minh" },
+            { "PLT", Pakistan },
             { "America/North_Dakota/Beulah", America_Central },
             { "timezone.excity.Asia/Makassar", "Makassar" },
             { "Pacific/Apia", Apia },
             { "Pacific/Niue", Niue },
             { "timezone.excity.Asia/Yekaterinburg", "Yekaterinburg" },
+            { "CST", America_Central },
             { "timezone.excity.Europe/Sofia", "S\u00f3ifia" },
             { "MST7MDT", America_Mountain },
             { "America/Monterrey", America_Central },
@@ -1980,6 +1944,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Calcutta", "Calc\u00fata" },
             { "Indian/Mahe", Seychelles },
             { "Asia/Aqtobe", Kazakhstan_Western },
+            { "CTT", China },
             { "timezone.excity.Asia/Gaza", "Gaza" },
             { "timezone.excity.Africa/Ceuta", "Ceuta" },
             { "Africa/Libreville", Africa_Western },
@@ -1989,6 +1954,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "timezone.excity.Antarctica/Troll", "Troll" },
             { "America/Aruba", Atlantic },
             { "America/North_Dakota/Center", America_Central },
+            { "PNT", America_Mountain },
             { "timezone.excity.Asia/Hong_Kong", "Hong Cong" },
             { "timezone.excity.America/Port-au-Prince", "Port-au-Prince" },
             { "America/Tijuana", America_Pacific },
@@ -1997,8 +1963,8 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Kwajalein", "Kwajalein" },
             { "SystemV/YST9", Gambier },
             { "Africa/Douala", Africa_Western },
-            { "America/Chihuahua", Mexico_Pacific },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Chihuahua", America_Central },
+            { "America/Ojinaga", America_Central },
             { "Asia/Hovd", Hovd },
             { "timezone.excity.Europe/Lisbon", "Liosp\u00f3in" },
             { "timezone.excity.Pacific/Gambier", "Gambier" },
@@ -2006,6 +1972,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "America/Santiago", Chile },
             { "timezone.excity.Europe/Zaporozhye", "Zaporozhye" },
             { "Asia/Baku", Azerbaijan },
+            { "ART", Europe_Eastern },
             { "America/Argentina/Ushuaia", Argentina },
             { "Atlantic/Reykjavik", GMT },
             { "Africa/Brazzaville", Africa_Western },
@@ -2016,17 +1983,8 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Kampala", "Kampala" },
             { "timezone.excity.Pacific/Chatham", "Chatham" },
             { "Africa/Dar_es_Salaam", Africa_Eastern },
-            { "Antarctica/Palmer",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Africa/Addis_Ababa", Africa_Eastern },
+            { "AST", Alaska },
             { "Europe/Uzhgorod", Europe_Eastern },
             { "timezone.excity.Asia/Colombo", "Colombo" },
             { "timezone.excity.Pacific/Port_Moresby", "Port Moresby" },
@@ -2044,6 +2002,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "Atlantic/South_Georgia", South_Georgia },
             { "Europe/Lisbon", Europe_Western },
             { "Asia/Harbin", China },
+            { "PRT", Atlantic },
             { "Asia/Novokuznetsk", Krasnoyarsk },
             { "timezone.excity.America/Cordoba", "C\u00f3rdoba" },
             { "timezone.excity.America/Cambridge_Bay", "Cambridge Bay" },
@@ -2063,6 +2022,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "timezone.excity.Australia/Sydney", "Sydney" },
             { "timezone.excity.Asia/Qatar", "Catar" },
             { "timezone.excity.America/Sitka", "Sitka" },
+            { "PST", America_Pacific },
             { "SystemV/EST5", America_Eastern },
             { "timezone.excity.Antarctica/Davis", "Davis" },
             { "America/Santo_Domingo", Atlantic },
@@ -2115,6 +2075,7 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "America/Porto_Velho", Amazon },
             { "America/Scoresbysund", Greenland_Eastern },
             { "Asia/Kamchatka", Kamchatka },
+            { "NST", New_Zealand },
             { "timezone.excity.Asia/Samarkand", "Samarkand" },
             { "Africa/Khartoum", Africa_Central },
             { "timezone.excity.Australia/Adelaide", "Adelaide" },
@@ -2162,31 +2123,11 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "Asia/Atyrau", Kazakhstan_Western },
             { "Australia/Darwin", Australia_Central },
             { "Asia/Kuala_Lumpur", Malaysia },
-            { "Asia/Famagusta",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Europe/Bratislava", Europe_Central },
             { "timezone.excity.Atlantic/Stanley", "Stanley" },
             { "Pacific/Tongatapu", Tonga },
             { "timezone.excity.Asia/Rangoon", "Rang\u00fan" },
             { "timezone.excity.Asia/Thimphu", "Thimphu" },
-            { "Europe/Ulyanovsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "timezone.excity.Asia/Dubai", "Dubai" },
             { "Arctic/Longyearbyen", Europe_Central },
             { "timezone.excity.Asia/Kuala_Lumpur", "Kuala Lumpur" },
@@ -2194,16 +2135,6 @@ public class TimeZoneNames_ga extends TimeZoneNamesBundle {
             { "Indian/Kerguelen", French_Southern },
             { "timezone.excity.Africa/Ouagadougou", "Ouagadougou" },
             { "timezone.excity.Africa/Gaborone", "Gaborone" },
-            { "Asia/Srednekolymsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Asia/Anadyr", Anadyr },
             { "timezone.excity.Indian/Chagos", "Chagos" },
             { "timezone.excity.Asia/Kabul", "Cab\u00fal" },
